/*
	*==============================*
	|      SMHI Weather v1.0       |
	| by Henrik 'TwoD' Danielsson  |
	| the_dragonwizard@hotmail.com |
	*==============================*

	More info in the readme files, now available in Swedish and English.
	
	Changelog
	1.0
	* Fixed a problem with wrong day/night symbols.
	* Better readme files in both Swedish and English!
	! VERSION 1.0 !

	0.93b->0.94b
	+ Added getCurrentSymbol(). (Requires a weather icon set)
	+ Added getCurrentSunUp()/Down().
	+ Added <sunup>, <sundown> and <downfall> to getCurrentString().
	+ Added <snow> to getForecastString().
	* Fixed reading from cached files.
	* Fixed a wind direction problem (North was undefined).

	0.92b->0.93b
	* Fixed error with overview images not being saved and shown.
	* Fixed the problem with special swedish (and other) characters!
	+ Added and changed some internal routines, to make it easier to create expansions.
	  
	0.91b->0.92b
	* Changed the getForecastSymbol function so it doesn't use the current time and date when ahead>0.
	
	0.9b->0.91b
	* Fixed suntime calculations...

*/

var PlaceId=10010110082; // Find the place id at the bottom of the script in the node arrays. Default is my home town :)
var SymbolFileExtension="png"; // The file extension of the symbol images. (Do not include the .)
var dirs=["?","N","","S","S","SV","V","NV","N"]; // Where the wind blows from. Clockwise order, starting with 1=Northeast.
var days=["Sndag","Mndag","Tisdag","Onsdag","Torsdag","Fredag","Lrdag"];  // Week starts with Sunday
var timeSteps={da:"Dag",na:"Natt",mo:"Morgon",em:"Eftermiddag",kv:"Kvll"};  //Day, Night, Morning, Afternoon, Evening
var timeStepTimes={da:"12:00", na:"00:00",mo:"06:00",em:"12:00",kv:"18:00"};
var UpdateInterval=20;   // How often the data should update, in minutes. Note that the SMHI data updates about every half or whole hour.
var useCharset="ISO-8859-1"; // ISO-8859-1 aka Latin 1 is what's being used by SMHI for the .js files. UTF-8 will be used for caches.

/*
	Current functions. This data represents the latest (observed) weather data.
*/

function getCurrentTemp(){
	// Gets the current temperature in degrees Celcius.
	return getForecastData_(0,"current");
}

function getCurrentHumidity(){
	// Gets the current air humidity in %.
	return getForecastData_(6,"current");
}

function getCurrentWindSpeed(){
	// Gets the current wind speed in m/s.
	return getForecastData_(4,"current");
}

function getCurrentWindDirection(){
 	// Gets the current wind direction in N,NE,E,SE,S,SW,W,NW headings.
	return dirs[getForecastData_(3,"current")];
}

function getCurrentDate(){
	// Gets the current date (yyyy-mm-dd), is here just to check if the forecast data is old.
	return getForecastData_(1,"current");
}

function getCurrentUpdatedTime(){
	// Gets the time for when the current data was updated.
	return getForecastData_(2,"current");
}

function getCurrentSunUp(){
	// Gets the time of sunrize
	var date=getForecastData_(1,"current");
	var sunData=getSuntimeData_(date)
	return sunData[0]?sunData[0]:false;
}

function getCurrentSunDown(){
	// Gets the time of sunrize
	var date=getForecastData_(1,"current");
	var sunData=getSuntimeData_(date)
	return sunData[1]?sunData[1]:false;
}

function getCurrentDownfall(){
	 // Gets the current downfall in mm/h.
	 return getForecastData_(5,"current");
}

function getCurrentSymbol(){
	// Returns the local path to the current symbol.
	var symbolNum=getForecastData_(7,"current");
	var date=getForecastData_(1,"current"); // Don't use new Date() to be sure there's a suntime defined for the latest date (which should be today).
	var sunData=getSuntimeData_(date);
	var sunUp=sunData[0];
	var sunDown=sunData[1];
	sunDown=sunDown<"01:00"?"23:59":sunDown // Fix needed if sun sets after midnight, or the calculations below will return incorrect day/night
	var currDate=new Date();
	var currLocalTime=(currDate.getHours()<10?"0"+currDate.getHours():currDate.getHours()) +":"+ (currDate.getMinutes()<10?"0"+currDate.getMinutes():currDate.getMinutes());
	var dir=(sunUp=='none'||sunUp <= currLocalTime && sunDown >= currLocalTime)?"Day":"Night";
	return SamDir+"Scripts/WeatherImgs/"+dir+"/"+symbolNum+"."+SymbolFileExtension;

}

function getCurrentString(format){
	// Takes a format string as an argument and replaces tags with forecast data.
	var temp=getForecastData_(0,"current");
	var fukt=getForecastData_(6,"current");
	var vhast=getForecastData_(4,"current");
	var vrikt=dirs[getForecastData_(3,"current")];
	var datum=getForecastData_(1,"current");
	var updated=getForecastData_(2,"current");
	var sunUp="",sunDown="";
	if(/<sunup>|<sundown>/i.test(format)){
		var sunData=getSuntimeData_(datum);
		sunUp=sunData[0]?sunData[0]:sunData;
		sunDown=sunData[1]?sunData[1]:sunData;
	}
	var downfall=getForecastData_(5,"current");
	return format.replace(/<temp>/ig,temp).replace(/<humidity>/ig,fukt).replace(/<windspeed>/ig,vhast).replace(/<winddir>/ig,vrikt).replace(/<date>/ig,datum).replace(/<updated>/ig,updated).replace(/<sunup>/ig,sunUp).replace(/<sundown>/ig,sunDown).replace(/<downfall>/ig,downfall)
}

/*
	Forecast functions. This data is used in the 5-day forecast.
*/

function getForecastTemp(ahead){
	// Gets the air temperature in degrees Celcius.
	return getForecastData_("temp",ahead);
}

function getForecastHumidity(ahead){
	// Gets the air humidity in %.
	return getForecastData_("fukt",ahead);
}

function getForecastWindSpeed(ahead){
	// Gets the forecast wind speed in m/s.
	return getForecastData_("vhast",ahead);
}

function getForecastWindDirection(ahead){
	// Gets the wind direction in N,NE,E,SE,S,SW,W,NW headings.
	return dirs[getForecastData_("vrikt",ahead)];
}

function getForecastDate(ahead){
	// Gets the date (yyyy-mm-dd) for which the forecast is valid.
	return getForecastData_("datum",ahead);
}

function getForecastWeekDay(ahead){
	// Gets the weekday for which the forecast is valid.
	return days[getForecastData_("vdag",ahead)];
}

function getForecastTimeOfDay(ahead){
	// Gets the time of day for which the forecast is valid.
	return timeSteps[getForecastData_("tidsteg",ahead)];
}

function getForecastRain(ahead){
	 // Gets the amount of rain in mm/h.
	 return getForecastData_("nbd",ahead);
}

function getForecastSnow(ahead){
	// Gets the amount of snow in mm/h.
	return getForecastData_("nbd_sno",ahead);
}

function getForecastSunUp(ahead){
	// Returns the time at which the sun comes up above the horizon.
	ahead=parseInt(ahead);
	ahead=isNaN(ahead)?0:ahead;
	var currDate=new Date(new Date().getTime()+ahead*86400000); // Get the date, look x days ahead.
	var date=currDate.getYear()+"-"+(currDate.getMonth()+1<10?"0"+(currDate.getMonth()+1):currDate.getMonth()+1)+"-"+(currDate.getDate()<10?"0"+currDate.getDate():currDate.getDate()); // Format the date "properly".
	var sunData=getSuntimeData_(date);
	return sunData?sunData[0]:false;
}

function getForecastSunDown(ahead){
	// Returns the time at which the sun goes down below the horizon.
	ahead=parseInt(ahead);
	ahead=isNaN(ahead)?0:ahead;
	var currDate=new Date(new Date().getTime()+ahead*86400000); // Get the date, look x days ahead.
	var date=currDate.getYear()+"-"+(currDate.getMonth()+1<10?"0"+(currDate.getMonth()+1):currDate.getMonth()+1)+"-"+(currDate.getDate()<10?"0"+currDate.getDate():currDate.getDate()); // Format the date "properly".
	var sunData=getSuntimeData_(date);
	return sunData?sunData[1]:false;
}

function getForecastSymbol(ahead){
	// Returns the local path to a forecast symbol.
	var symbolNum=getForecastData_("symbol",ahead);
	var date=getForecastData_("datum",ahead);
	var sunData=getSuntimeData_(date);
	var sunUp=sunData[0];
	var sunDown=sunData[1];
	sunDown=sunDown<"01:00"?"23:59":sunDown // Fix needed if sun sets after midnight, or the calculations below will return incorrect day/night
	var currDate=new Date();
	var currLocalTime=ahead==0?((currDate.getHours()<10?"0"+currDate.getHours():currDate.getHours())+":"+(currDate.getMinutes()<10?"0"+currDate.getMinutes():currDate.getMinutes())):timeStepTimes[getForecastData_("tidsteg",ahead)];
	var dir=(sunUp=='none'||sunUp <= currLocalTime && sunDown >= currLocalTime)?"Day":"Night";
	return SamDir+"Scripts/WeatherImgs/"+dir+"/"+symbolNum+"."+SymbolFileExtension;
}

function getForecastImage(when){
	// Grabs an overview forecast image. Returns a local path to the file.
	if(!FS){return "No FileSystem Object available";}
	var placeIndex=getIndexFromId_(PlaceId); // Find out where int the nodeArray we are.
	var currentPlace=nodeArray[placeIndex];
	var parentIndex=currentPlace[2][currentPlace[2].length-1]  // Use the map for the parent location since cities don't have maps. Will be off if a region is selected.
	var parentId=nodeArray[parentIndex][1].toString()+"0";  // For some reason, a 0 (or sometimes 1) must be appended to get the correct data.
	var hasError=false,smhilandimages=false; // smhilandimages,smhiavailabledates & smhiavailableareas are (re)defined in forecastmap_###.js
	when=parseInt(when);
	when=isNaN(when)?0:when;
	try{    // Check the cached image file, is old. If not, return the path to it, otherwise attempt to update it.
		var filepath = FS.GetSpecialFolder(2)+"\\ForecastMap"+parentId+"_"+when+".png";
		if(FS.FileExists(filepath)){
			var file=FS.GetFile(filepath);
			if(new Date().getTime()-new Date(file.DateLastModified).getTime()<UpdateInterval*60000){
				return filepath;
			}
		}
	}
	catch(er){}
	try{
 		var downData=getPage_(dataPath+"forecastmap_"+nodeArray[parentIndex][1]+".js","ForecastMap_"+parentId,true);
		if(downData){
			eval(downData);
		}
		else{
			hasError=true;
		}
	}
	catch(er){
		hasError=true;
	}
	if(!smhilandimages || hasError){
		return "Error In ForecastMap Data";
	}
	if(new RegExp("^"+smhiavailableareas.join("$|^")+"$").test(parentId)){   // Check if the area exists in the list.
		var timeStep=0; // Begin looking for the first active date in the list .
		while(smhiavailabledates[parentId][timeStep+1]=="-1"){
			timeStep+=2; // If the date was deactivated, jump two steps in the array. 1 past the date and 1 past the time/active value.
		}
		timeStep+=(2*when);
		var timeStamp=parentId+"_"+smhiavailabledates[parentId][timeStep]+"_"+smhiavailabledates[parentId][timeStep+1]; // Get the key for the image corresponding to the date.
		var imageData=downloadFile_(smhilandimages[timeStamp][0],true);  // Download the image as binary data.
		var filePath="Load Error";
		if(typeof imageData!="boolean"){ // A Stream object has typeof imageData=="unknown"
			filePath=writeFile_("SWEWeather_ForecastMap"+parentId+"_"+when+".png",imageData,true); // Write it to a local binary file.
		}
		else{
			filePath="Data Corrupted";
		}
		filePath=filePath?filePath:"Save Error";
		return filePath;
	}
	return "Date Not Found";
}

function getSatelliteImage(){
	// Grabs the latest satellite image. Returns a local path to the file.
	var hasError=false,smhisatelliteimages=false; // smhisatelliteimages is defined in satellit.js
	if(!FS){return false;}
	try{    // Check the cached image file, is old. If not, return the path to it, otherwise attempt to update it.
		var filepath = FS.GetSpecialFolder(2)+"\\SWEWeather_SatelliteMap.jpg";
		if(FS.FileExists(filepath)){
			var file=FS.GetFile(filepath);
			if(new Date().getTime()-new Date(file.DateLastModified).getTime()<10*60000){
				return filepath;
			}
		}
	}
	catch(er){}
	try{
 		var downData=getPage_(dataPath+"satellit.js","Satellite",true);
		if(downData){
			eval(downData);
		}
		else{
			hasError=true;
		}
	}
	catch(er){
		hasError=true;
	}
	if(!smhisatelliteimages || hasError){
		return "Error In Map Data";
	}
	var imageData=downloadFile_(smhisatelliteimages[0][0],true);  // Download the image as binary data.
	var filePath="Load Error";
	if(typeof imageData!="boolean"){ // A Stream object has typeof imageData=="unknown"
		filePath=writeFile_("SWEWeather_SatelliteMap.jpg",imageData,true); // Write it to a local binary file.
	}
	else{
		filePath="Data Corrupted";
	}
	filePath=filePath?filePath:"Save Error";
	return filePath;
}

function getForecastString(format,ahead){
	// Takes a format string as an argument and replaces tags with forecast data.
	var temp=getForecastData_("temp",ahead);
	var fukt=getForecastData_("fukt",ahead);
	var vhast=getForecastData_("vhast",ahead);
	var vrikt=dirs[getForecastData_("vrikt",ahead)];
	var datum=getForecastData_("datum",ahead);
	var vdag=getForecastData_("vdag",ahead);
	var tidsteg=getForecastData_("tidsteg",ahead);
	var ndb=getForecastData_("ndb",ahead);
	var snow=getForecastData_("ndb_sno",ahead);
	var sunup="",sundown="";
	if(/<sunup>|<sundown>/i.test(format)){
		sunup=getForecastSunUp(ahead);
		sundown=getForecastSunDown(ahead);
	}
	return format.replace(/<temp>/ig,temp).replace(/<humidity>/ig,fukt).replace(/<windspeed>/ig,vhast).replace(/<winddir>/ig,vrikt).replace(/<date>/ig,datum).replace(/<weekday>/ig,days[vdag]).replace(/<tod>/ig,timeSteps[tidsteg]).replace(/<rain>/ig,ndb).replace(/<snow>/ig,snow).replace(/<sunup>/ig,sunup).replace(/<sundown>/ig,sundown);
}

/*
	Global non-public variables and functions.
*/

// These variables are used to store the downloaded data between accesses.
//Since the data Arrays are declared with var, they would otherwise only be available to the function which downloaded and parsed them.
var MemCache=[],globalValuesArray,globalOrtsNamn,globalNuvaderArr,globalSoltidArray

var dataPath = 'http://www.smhi.se/natvaderDL/data/jsfiles/' // The path to the .js data files.
var SamDir=new ActiveXObject("WScript.Shell").RegRead("HKEY_CURRENT_USER\\Software\\Serious Samurize\\General\\DirPath").replace(/\\/g,"/");
// Init commonly used ActiveX Objects for disc IO and HTTP requests.
try{var FS=new ActiveXObject("Scripting.FileSystemObject");}catch(er){var FS=false;}
try{var ADODBS=new ActiveXObject("ADODB.Stream");}catch(er){var ADODBS=false;}
try{var XMLHTTP=new ActiveXObject("Microsoft.XMLHTTP");}catch(er){var XMLHTTP=false;}

function getForecastData_(what,when){
	if(!globalValuesArray){ // Query the global object to see if we have already loaded the data array(s).
		var hasError=false,valuesArray=false; // valuesArray,nuvaderArr & ortsNamn are defined in forecast_###.js
		try{
			var downData=getPage_(dataPath+"forecast_"+PlaceId+".js","Forecast_"+PlaceId,true);
			if(downData){eval(downData);}else{hasError=true;}
		}
		catch(er){hasError=true;}
		if(!valuesArray || hasError){return false;}
		globalValuesArray=valuesArray;// Used to move the data out of the function scope in case of multiple calls.
		globalNuvaderArr=nuvaderArr;
		globalOrtsNamn=ortsNamn;
	}
	if(what=="ortsNamn"){return globalOrtsNamn;}
	if(when=="current"){return globalNuvaderArr[what];}
	else{
		when=parseInt(when);
		when=isNaN(when)?0:when;
		var timeStep=0;
		while(!globalValuesArray[timeStep+"-active"]){timeStep++;}
		return globalValuesArray[(timeStep+when)+"-"+what];
	}
}

function getSuntimeData_(date){
	// Returns an Array: [String SunUpTime, String SunDownTime]
	if(!globalSoltidArray){ // Query the global object to see if we have already loaded the data array.
		var hasError=false,soltidArray=false; // soltidArray is defined in suntime_###.js
		try{
			var downData=getPage_(dataPath+"suntime_"+PlaceId+".js","Suntime_"+PlaceId,true);
			if(downData){eval(downData);}else{hasError=true;}
		}
		catch(er){hasError=true;}
		if(!soltidArray || hasError){
			return false;
		}
		globalSoltidArray=soltidArray; // Used to move the data out of the function scope in case of multiple calls.
		soltidArray=null;
	}
	for (var sunData=[],i=0;i<globalSoltidArray.length;i++){ // Rearrange the array for easier access.
		sunData[globalSoltidArray[i][0]]=[globalSoltidArray[i][2],globalSoltidArray[i][3]]
	}
	return sunData[date]?sunData[date]:date;
}

function getPage_(url,cacheName,includeHtml,noReadCache,noSaveCache){
	// Grabs and caches the complete source of a page at any given url. Returns the source with or without HTML tags.
	var trackerCache="SWEWeather_"+cacheName+".txt";  // Set the full name of the cache file.
	var txt=noReadCache?"":(MemCache[trackerCache]?MemCache[trackerCache]:readFile_(trackerCache,UpdateInterval));  // Read the cached file, if any.
	if(!txt){
		txt=downloadFile_(url,false);  // Download the page source.
		if(!txt){
			return "Read Error";
		}
		if(!noSaveCache){  // Do we have anything to cache?
			MemCache[trackerCache]=txt;
			writeFile_(trackerCache,txt);
		}
	}
	return !includeHtml && txt?removeHTML_(txt):txt;
}

function downloadFile_(URL,asBinary){
	// Basic function to grab a text/binary file.
	// NOTE: Returns a Stream object if binary read is successful!
	// A Stream object can't be used as a normal String since its type is unknown to JS.
	// Use: if(typeof returnedValue == "boolean"); to know if the read was unsuccessful.
	if(!XMLHTTP){
		return false;
	}
	try{  // Catch all errors
		if(!/^http:\/\//i.test(URL)){
			URL="http://"+URL
		}
		XMLHTTP.Open("GET",URL+(false?"":"?"+Math.random()),false);  // Set what to download and add a seed to make sure we don't get a cached version.
		XMLHTTP.Send(null);  // Send the request and hope we get a response.
		if(XMLHTTP.Status==200){  // 200=OK
			if(asBinary){
				return XMLHTTP.responseBody;
			}
			else{
				var txt="No file contents found!";
				if(ADODBS){
					try{
						ADODBS.Open();
						ADODBS.Type=1;    // Binary
						ADODBS.Write(XMLHTTP.responseBody);  // Write the response as a byte stream.
						ADODBS.Position=0;   // Move back to the start of the stream to be able to change type and charset.
						ADODBS.Type=2;  // Text
						ADODBS.Charset=useCharset; // Default to Latin 1 Western, West European.
						txt=ADODBS.ReadText();
						ADODBS.Close();
					}
					catch(er){
						txt=XMLHTTP.responseText;  // Something failed, default back to responseText, UTF-8 is forced.
					}
				}
				else{
					txt=XMLHTTP.responseText;  // No ADODB Stream available, default back to responseText, UTF-8 forced.
				}
				return txt;
			}
		}
	}
	catch(e){} // Error!
	return false;
}

function readFile_(fileName,modified_max_time){
	// Basic function to read a text file. Returns false if the file was updated too long ago.
	// Only reads UTF-8 or UTF-16!
	if(!FS || !ADODBS){return false;}
	try{
		var filepath = FS.GetSpecialFolder(2)+"\\"+fileName;			// Find the temp folder and add the filename.
		if(FS.FileExists(filepath)){						// Anyone there?
			var file=FS.GetFile(filepath);					// Get the file so we can use it.
			var filetime = new Date(file.DateLastModified).getTime();	// When was it last modified? In milliseconds...
			var now = new Date().getTime();					// What's the time? In ms...
			if(!modified_max_time || now-filetime<modified_max_time*60000){	// The downloaded file is less than modified_max_time minutes old or no modified_max_time was set.
				ADODBS.Open();
				ADODBS.Type=2; // Text
				ADODBS.Charset="UTF-8";
				ADODBS.LoadFromFile(filepath);
				var txt=ADODBS.ReadText();
				ADODBS.Close();						// Job done!
				return txt;
			}
		}
	}
	catch(er){}
	return false // The file was either too old or not found.
}

function writeFile_(fileName,contents,writeAsBinary){
	// Basic function to write a text/binary file.
	// Writes as UTF-8 if not as byte stream.
	// Returns the path to the written file.
	if(!FS || !ADODBS){return false;}
	try{
		var filepath=FS.GetSpecialFolder(2)+"\\"+fileName; // Tempfolder
		ADODBS.Type = writeAsBinary?1:2;// 1=adTypeBinary, 2=adTypeText;
		ADODBS.Open();
		if(writeAsBinary){
			ADODBS.Write(contents);
		}
		else{
			ADODBS.Charset="UTF-8";
			ADODBS.WriteText(contents);
		}
		ADODBS.SaveToFile(filepath, 2); // 2=adSaveCreateOverWrite
		ADODBS.Close()
		return filepath;
	}
	catch(er){}
	return false;
}


function getIndexFromId_(id){
	for(var i=nodeArray.length-1;i>=0;i--){
		if(nodeArray[i][1]==id){
			return i
		}
	}
}

var nodeArray=[];
nodeArray[0]	= ["Vrlden", 1, null, [2,3,6,1,4,5]];
  nodeArray[1]	= ["Europa", 10, [0], [19,12,15,10,11,9,13,14,16,17,18,8,21,22,23,24,25,20,26,27,7,28,29,30,31,32,33,34]];
  nodeArray[2]	= ["Afrika", 11, [0], [747,748,749,750,751,752,753,754,755,756,757,758,759,760,761,762,763,764,765,766,767,768,769,770,771,772,773,774,775]];
  nodeArray[3]	= ["Asien", 12, [0], [711,712,713,714,715,716,717,718,719,720,721,722,723,724,725,726,727,728,729,730,731,732,733,734,735,736,737,738,746,739,740,741,742,743,744,745]];
  nodeArray[4]	= ["Nordamerika", 13, [0], [657,681,682,683,684,685,686,687,688,689,690,691,692,693,694,695,696,697,698,699,700,701,702,703,710,704,705,706,707,708,709]];
  nodeArray[5]	= ["Sydamerika", 14, [0], [658,659,660,661,662,663,664,665,666,667,668,669,670,671]];
  nodeArray[6]	= ["Australien", 15, [672,673,674,675,676,677,678,679,680]];
  nodeArray[7]	= ["Sverige", 1001, [0,1], [35,39,40,38,37,36]];
  nodeArray[8]	= ["Norge", 1002, [0,1], [331,332,333,334,335,336,337,338,339,340,341]];
  nodeArray[9]	= ["Finland", 1003, [0,1], [343,344,345,346,347,348,349,350,351,352,353,354,355,356,357,358,359,374,360,361,362,363,364,365,366,367,368,369,370,371,372,373]];
  nodeArray[10]	= ["Bulgarien", 1005, [0,1], [383,384,385,381,386,382]];
  nodeArray[11]	= ["Danmark", 1007, [0,1], [392,393,405,402,404,400,399,391,401,395,409,394,410,406,396,408,407,398,403,397]];
  nodeArray[12]	= ["Baltikum", 1008, [0,1], [508,507,511,510,506,412,512,414,505,411,413,509]];
  nodeArray[13]	= ["Frankrike", 1010, [0,1], [415,416,422,417,424,418,425,429,428,423,431,432,426,419,420,433,430,427,421]];
  nodeArray[14]	= ["Grekland", 1011, [0,1], [434,444,435,446,440,439,443,438,436,442,441,445,437]];
  nodeArray[15]	= ["Benelux", 1012, [0,1], [447,379,450,376,375,378,380,448,451,377,486,449]];
  nodeArray[16]	= ["Irland", 1013, [0,1], [453,452,454,455]];
  nodeArray[17]	= ["Island", 1014, [0,1], [458,459,457,456,460]];
  nodeArray[18]	= ["Italien", 1015, [0,1], [471,481,461,472,473,462,463,474,475,464,465,466,467,476,477,478,468,469,479,480,470]];
  nodeArray[19]	= ["Balkan", 1016, [0,1], [496,495,490,500,489,485,488,487,491,499,484,492,497,483,501,498,493,482,494]];
  nodeArray[20]	= ["Slovakien", 1018, [0,1], [502,503,504]];
  nodeArray[21]	= ["Polen", 1020, [0,1], [520,523,521,514,528,522,519,524,518,529,516,527,526,515,525,513,517]];
  nodeArray[22]	= ["Portugal", 1021, [0,1], [535,536,537,538,530,531,534,532,533]];
  nodeArray[23]	= ["Rumnien", 1022, [0,1], [540,539,542,541,543,544]];
  nodeArray[24]	= ["Ryssland", 1023, [0,1], [545,553,546,548,551,547,549,552,550]];
  nodeArray[25]	= ["Schweiz", 1024, [0,1], [558,554,559,555,556,557]];
  nodeArray[26]	= ["Spanien", 1025, [0,1], [578,560,580,561,572,579,577,569,571,570,568,562,563,564,565,573,581,566,567,576,574,575]];
  nodeArray[27]	= ["Storbritannien", 1026, [0,1], [593,590,594,588,582,584,595,586,583,585,587,592,589,591]];
  nodeArray[28]	= ["Tjeckien", 1027, [0,1], [598,599,597,596]];
  nodeArray[29]	= ["Turkiet", 1029, [0,1], [605,600,601,603,604,602,606,387,390,389,388,607]];
  nodeArray[30]	= ["Tyskland", 1030, [0,1], [608,617,612,613,616,609,627,611,614,618,610,615,621,625,623,626,620,624,622,619]];
  nodeArray[31]	= ["Ukraina", 1031, [0,1], [630,631,629,632,628]];
  nodeArray[32]	= ["Ungern", 1032, [633,638,636,637,634,635,639]];
  nodeArray[33]	= ["Vitryssland", 1033, [0,1], [642,641,645,640,643,644,646]];
  nodeArray[34]	= ["sterrike", 1034, [0,1], [647,656,654,648,649,655,653,650,651,652]];
  nodeArray[35]	= ["Gtaland", 100101, [0,1,7], [129,130,131,132,124,133,134,135,136,263,137,138,139,125,140,141,142,143,144,145,146,147,148,149,150,151,126,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,127,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,249,250,251,252,248,253,254,257,258,128,255,256,259,260,261,262]];
  nodeArray[36]	= ["stra Svealand", 100102, [0,1,7], [287,292,293,294,295,296,278,297,298,279,299,280,300,301,302,303,288,281,282,304,305,283,306,307,290,308,291,284,309,310,285,311,312,313,314,315,286,316,317,318,319,320,321,322,323,324,325,326,327,289,328,329,330]];
  nodeArray[37]	= ["Vstra Svealand", 100103, [0,1,7], [66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,106,108]];
  nodeArray[38]	= ["Sdra Norrland", 100104, [0,1,7], [41,60,42,55,56,61,59,43,44,45,62,63,57,64,46,58,47,48,49,65,50,51,52,53,54]];
  nodeArray[39]	= ["Mellersta Norrland", 100105, [0,1,7], [109,110,111,112,113,114,115,116,117,118,119,120,121,122,123]];
  nodeArray[40]	= ["Norra Norrland", 100106, [0,1,7], [264,265,266,267,268,269,270,271,272,273,274,275,276,277]];
  nodeArray[41]	= ["Berg", 10010423026, [0,1,7,38], null];
  nodeArray[42]	= ["Brcke", 10010423005, [0,1,7,38], null];
  nodeArray[43]	= ["Hrnsand", 10010422080, [0,1,7,38], null];
  nodeArray[44]	= ["Kramfors", 10010422082, [0,1,7,38], null];
  nodeArray[45]	= ["Krokom", 10010423009, [0,1,7,38], null];
  nodeArray[46]	= ["Ragunda", 10010423003, [0,1,7,38], null];
  nodeArray[47]	= ["Sollefte", 10010422083, [0,1,7,38], null];
  nodeArray[48]	= ["Strmsund", 10010423013, [0,1,7,38], null];
  nodeArray[49]	= ["Sundsvall", 10010422081, [0,1,7,38], null];
  nodeArray[50]	= ["Timr", 10010422062, [0,1,7,38], null];
  nodeArray[51]	= ["nge", 10010422060, [0,1,7,38], null];
  nodeArray[52]	= ["re", 10010423021, [0,1,7,38], null];
  nodeArray[53]	= ["rnskldsvik", 10010422084, [0,1,7,38], null];
  nodeArray[54]	= ["stersund", 10010423080, [0,1,7,38], null];
  nodeArray[55]	= ["Gvle", 10010421080, [0,1,7,38], null];
  nodeArray[56]	= ["Hofors", 10010421004, [0,1,7,38], null];
  nodeArray[57]	= ["Ockelbo", 10010421001, [0,1,7,38], null];
  nodeArray[58]	= ["Sandviken", 10010421081, [0,1,7,38], null];
  nodeArray[59]	= ["Hrjedalen", 10010423061, [0,1,7,38], null];
  nodeArray[60]	= ["Bollns", 10010421083, [0,1,7,38], null];
  nodeArray[61]	= ["Hudiksvall", 10010421084, [0,1,7,38], null];
  nodeArray[62]	= ["Ljusdal", 10010421061, [0,1,7,38], null];
  nodeArray[63]	= ["Nordanstig", 10010421032, [0,1,7,38], null];
  nodeArray[64]	= ["Ovanker", 10010421021, [0,1,7,38], null];
  nodeArray[65]	= ["Sderhamn", 10010421082, [0,1,7,38], null];
  nodeArray[66]	= ["Arvika", 10010317084, [0,1,7,37], null];
  nodeArray[67]	= ["Askersund", 10010318082, [0,1,7,37], null];
  nodeArray[68]	= ["Avesta", 10010320084, [0,1,7,37], null];
  nodeArray[69]	= ["Borlnge", 10010320081, [0,1,7,37], null];
  nodeArray[70]	= ["Degerfors", 10010318062, [0,1,7,37], null];
  nodeArray[71]	= ["Eda", 10010317030, [0,1,7,37], null];
  nodeArray[72]	= ["Falun", 10010320080, [0,1,7,37], null];
  nodeArray[73]	= ["Filipstad", 10010317082, [0,1,7,37], null];
  nodeArray[74]	= ["Forshaga", 10010317063, [0,1,7,37], null];
  nodeArray[75]	= ["Gagnef", 10010320026, [0,1,7,37], null];
  nodeArray[76]	= ["Grums", 10010317064, [0,1,7,37], null];
  nodeArray[77]	= ["Hagfors", 10010317083, [0,1,7,37], null];
  nodeArray[78]	= ["Hallsberg", 10010318061, [0,1,7,37], null];
  nodeArray[79]	= ["Hammar", 10010317061, [0,1,7,37], null];
  nodeArray[80]	= ["Hedemora", 10010320083, [0,1,7,37], null];
  nodeArray[81]	= ["Hllefors", 10010318063, [0,1,7,37], null];
  nodeArray[82]	= ["Karlskoga", 10010318083, [0,1,7,37], null];
  nodeArray[83]	= ["Karlstad", 10010317080, [0,1,7,37], null];
  nodeArray[84]	= ["Kil", 10010317015, [0,1,7,37], null];
  nodeArray[85]	= ["Kristinehamn", 10010317081, [0,1,7,37], null];
  nodeArray[86]	= ["Kumla", 10010318081, [0,1,7,37], null];
  nodeArray[87]	= ["Lax", 10010318060, [0,1,7,37], null];
  nodeArray[88]	= ["Lekeberg", 10010318014, [0,1,7,37], null];
  nodeArray[89]	= ["Leksand", 10010320029, [0,1,7,37], null];
  nodeArray[90]	= ["Lindesberg", 10010318085, [0,1,7,37], null];
  nodeArray[91]	= ["Ljusnarsberg", 10010318064, [0,1,7,37], null];
  nodeArray[92]	= ["Ludvika", 10010320085, [0,1,7,37], null];
  nodeArray[93]	= ["Malung", 10010320023, [0,1,7,37], null];
  nodeArray[94]	= ["Mora", 10010320062, [0,1,7,37], null];
  nodeArray[95]	= ["Munkfors", 10010317062, [0,1,7,37], null];
  nodeArray[96]	= ["Nora", 10010318084, [0,1,7,37], null];
  nodeArray[97]	= ["Orsa", 10010320034, [0,1,7,37], null];
  nodeArray[98]	= ["Rttvik", 10010320031, [0,1,7,37], null];
  nodeArray[99]	= ["Smedjebacken", 10010320061, [0,1,7,37], null];
  nodeArray[100]	= ["Storfors", 10010317060, [0,1,7,37], null];
  nodeArray[101]	= ["Sunne", 10010317066, [0,1,7,37], null];
  nodeArray[102]	= ["Sffle", 10010317085, [0,1,7,37], null];
  nodeArray[103]	= ["Ster", 10010320082, [0,1,7,37], null];
  nodeArray[104]	= ["Torsby", 10010317037, [0,1,7,37], null];
  nodeArray[105]	= ["Vansbro", 10010320021, [0,1,7,37], null];
  nodeArray[106]	= ["rjng", 10010317065, [0,1,7,37], null];
  nodeArray[107]	= ["lvdalen", 10010320039, [0,1,7,37], null];
  nodeArray[108]	= ["rebro", 10010318080, [0,1,7,37], null];
  nodeArray[109]	= ["Bjurholm", 10010524003, [0,1,7,39], null];
  nodeArray[110]	= ["Dorotea", 10010524025, [0,1,7,39], null];
  nodeArray[111]	= ["Lycksele", 10010524081, [0,1,7,39], null];
  nodeArray[112]	= ["Mal", 10010524018, [0,1,7,39], null];
  nodeArray[113]	= ["Nordmaling", 10010524001, [0,1,7,39], null];
  nodeArray[114]	= ["Norsj", 10010524017, [0,1,7,39], null];
  nodeArray[115]	= ["Robertsfors", 10010524009, [0,1,7,39], null];
  nodeArray[116]	= ["Skellefte", 10010524082, [0,1,7,39], null];
  nodeArray[117]	= ["Sorsele", 10010524022, [0,1,7,39], null];
  nodeArray[118]	= ["Storuman", 10010524021, [0,1,7,39], null];
  nodeArray[119]	= ["Ume", 10010524080, [0,1,7,39], null];
  nodeArray[120]	= ["Vilhelmina", 10010524062, [0,1,7,39], null];
  nodeArray[121]	= ["Vindeln", 10010524004, [0,1,7,39], null];
  nodeArray[122]	= ["Vnns", 10010524060, [0,1,7,39], null];
  nodeArray[123]	= ["sele", 10010524063, [0,1,7,39], null];
  nodeArray[124]	= ["Bengtsfors", 10010115060, [0,1,7,35], null];
  nodeArray[125]	= ["Dals-Ed", 10010115004, [0,1,7,35], null];
  nodeArray[126]	= ["Gullspng", 10010116043, [0,1,7,35], null];
  nodeArray[127]	= ["Mellerud", 10010115061, [0,1,7,35], null];
  nodeArray[128]	= ["ml", 10010115085, [0,1,7,35], null];
  nodeArray[129]	= ["Ale", 10010115021, [0,1,7,35], null];
  nodeArray[130]	= ["Alingss", 10010115082, [0,1,7,35], null];
  nodeArray[131]	= ["Alvesta", 10010107064, [0,1,7,35], null];
  nodeArray[132]	= ["Aneby", 10010106004, [0,1,7,35], null];
  nodeArray[133]	= ["Bjuv", 10010112060, [0,1,7,35], null];
  nodeArray[134]	= ["Bollebygd", 10010114043, [0,1,7,35], null];
  nodeArray[135]	= ["Borgholm", 10010108085, [0,1,7,35], null];
  nodeArray[136]	= ["Bors", 10010115083, [0,1,7,35], null];
  nodeArray[137]	= ["Bromlla", 10010111062, [0,1,7,35], null];
  nodeArray[138]	= ["Burlv", 10010112031, [0,1,7,35], null];
  nodeArray[139]	= ["Bstad", 10010111068, [0,1,7,35], null];
  nodeArray[140]	= ["Eksj", 10010106086, [0,1,7,35], null];
  nodeArray[141]	= ["Emmaboda", 10010108062, [0,1,7,35], null];
  nodeArray[142]	= ["Eslv", 10010112085, [0,1,7,35], null];
  nodeArray[143]	= ["Essunga", 10010116003, [0,1,7,35], null];
  nodeArray[144]	= ["Falkenberg", 10010113082, [0,1,7,35], null];
  nodeArray[145]	= ["Falkping", 10010116086, [0,1,7,35], null];
  nodeArray[146]	= ["Finspng", 10010105062, [0,1,7,35], null];
  nodeArray[147]	= ["Frgelanda", 10010115007, [0,1,7,35], null];
  nodeArray[148]	= ["Gislaved", 10010106062, [0,1,7,35], null];
  nodeArray[149]	= ["Gnosj", 10010106017, [0,1,7,35], null];
  nodeArray[150]	= ["Gotland", 10010109080, [0,1,7,35], null];
  nodeArray[151]	= ["Grstorp", 10010116002, [0,1,7,35], null];
  nodeArray[152]	= ["Gteborg", 10010114080, [0,1,7,35], null];
  nodeArray[153]	= ["Gtene", 10010116061, [0,1,7,35], null];
  nodeArray[154]	= ["Habo", 10010116023, [0,1,7,35], null];
  nodeArray[155]	= ["Halmstad", 10010113080, [0,1,7,35], null];
  nodeArray[156]	= ["Helsingborg", 10010112083, [0,1,7,35], null];
  nodeArray[157]	= ["Herrljunga", 10010115066, [0,1,7,35], null];
  nodeArray[158]	= ["Hjo", 10010116084, [0,1,7,35], null];
  nodeArray[159]	= ["Hultsfred", 10010108060, [0,1,7,35], null];
  nodeArray[160]	= ["Hylte", 10010113015, [0,1,7,35], null];
  nodeArray[161]	= ["Hrryda", 10010114001, [0,1,7,35], null];
  nodeArray[162]	= ["Hssleholm", 10010111083, [0,1,7,35], null];
  nodeArray[163]	= ["Hgans", 10010112084, [0,1,7,35], null];
  nodeArray[164]	= ["Hgsby", 10010108021, [0,1,7,35], null];
  nodeArray[165]	= ["Hrby", 10010112066, [0,1,7,35], null];
  nodeArray[166]	= ["Hr", 10010112067, [0,1,7,35], null];
  nodeArray[167]	= ["Jnkping", 10010106080, [0,1,7,35], null];
  nodeArray[168]	= ["Kalmar", 10010108080, [0,1,7,35], null];
  nodeArray[169]	= ["Karlsborg", 10010116037, [0,1,7,35], null];
  nodeArray[170]	= ["Karlshamn", 10010110082, [0,1,7,35], null];
  nodeArray[171]	= ["Karlskrona", 10010110080, [0,1,7,35], null];
  nodeArray[172]	= ["Kinda", 10010105013, [0,1,7,35], null];
  nodeArray[173]	= ["Klippan", 10010111066, [0,1,7,35], null];
  nodeArray[174]	= ["Kristianstad", 10010111080, [0,1,7,35], null];
  nodeArray[175]	= ["Kungsbacka", 10010113084, [0,1,7,35], null];
  nodeArray[176]	= ["Kunglv", 10010114082, [0,1,7,35], null];
  nodeArray[177]	= ["Kvlinge", 10010112061, [0,1,7,35], null];
  nodeArray[178]	= ["Laholm", 10010113081, [0,1,7,35], null];
  nodeArray[179]	= ["Landskrona", 10010112082, [0,1,7,35], null];
  nodeArray[180]	= ["Lerum", 10010115024, [0,1,7,35], null];
  nodeArray[181]	= ["Lessebo", 10010107061, [0,1,7,35], null];
  nodeArray[182]	= ["Lidkping", 10010116081, [0,1,7,35], null];
  nodeArray[183]	= ["Lilla Edet", 10010115062, [0,1,7,35], null];
  nodeArray[184]	= ["Linkping", 10010105080, [0,1,7,35], null];
  nodeArray[185]	= ["Ljungby", 10010107081, [0,1,7,35], null];
  nodeArray[186]	= ["Lomma", 10010112062, [0,1,7,35], null];
  nodeArray[187]	= ["Lund", 10010112081, [0,1,7,35], null];
  nodeArray[188]	= ["Lysekil", 10010114084, [0,1,7,35], null];
  nodeArray[189]	= ["Malm", 10010112080, [0,1,7,35], null];
  nodeArray[190]	= ["Mariestad", 10010116080, [0,1,7,35], null];
  nodeArray[191]	= ["Mark", 10010115063, [0,1,7,35], null];
  nodeArray[192]	= ["Markaryd", 10010107067, [0,1,7,35], null];
  nodeArray[193]	= ["Mjlby", 10010105086, [0,1,7,35], null];
  nodeArray[194]	= ["Motala", 10010105083, [0,1,7,35], null];
  nodeArray[195]	= ["Mullsj", 10010116022, [0,1,7,35], null];
  nodeArray[196]	= ["Munkedal", 10010114030, [0,1,7,35], null];
  nodeArray[197]	= ["Mlndal", 10010114081, [0,1,7,35], null];
  nodeArray[198]	= ["Mnsters", 10010108061, [0,1,7,35], null];
  nodeArray[199]	= ["Mrbylnga", 10010108040, [0,1,7,35], null];
  nodeArray[200]	= ["Norrkping", 10010105081, [0,1,7,35], null];
  nodeArray[201]	= ["Nybro", 10010108081, [0,1,7,35], null];
  nodeArray[202]	= ["Nssj", 10010106082, [0,1,7,35], null];
  nodeArray[203]	= ["Olofstrm", 10010110060, [0,1,7,35], null];
  nodeArray[204]	= ["Orust", 10010114021, [0,1,7,35], null];
  nodeArray[205]	= ["Osby", 10010111063, [0,1,7,35], null];
  nodeArray[206]	= ["Oskarshamn", 10010108082, [0,1,7,35], null];
  nodeArray[207]	= ["Partille", 10010114002, [0,1,7,35], null];
  nodeArray[208]	= ["Perstorp", 10010111065, [0,1,7,35], null];
  nodeArray[209]	= ["Ronneby", 10010110081, [0,1,7,35], null];
  nodeArray[210]	= ["Simrishamn", 10010111081, [0,1,7,35], null];
  nodeArray[211]	= ["Sjbo", 10010112065, [0,1,7,35], null];
  nodeArray[212]	= ["Skara", 10010116082, [0,1,7,35], null];
  nodeArray[213]	= ["Skurup", 10010112064, [0,1,7,35], null];
  nodeArray[214]	= ["Skvde", 10010116083, [0,1,7,35], null];
  nodeArray[215]	= ["Sotens", 10010114027, [0,1,7,35], null];
  nodeArray[216]	= ["Staffanstorp", 10010112030, [0,1,7,35], null];
  nodeArray[217]	= ["Stenungsund", 10010114015, [0,1,7,35], null];
  nodeArray[218]	= ["Strmstad", 10010114086, [0,1,7,35], null];
  nodeArray[219]	= ["Svalv", 10010112014, [0,1,7,35], null];
  nodeArray[220]	= ["Svedala", 10010112063, [0,1,7,35], null];
  nodeArray[221]	= ["Svenljunga", 10010115065, [0,1,7,35], null];
  nodeArray[222]	= ["Svsj", 10010106084, [0,1,7,35], null];
  nodeArray[223]	= ["Sderkping", 10010105082, [0,1,7,35], null];
  nodeArray[224]	= ["Slvesborg", 10010110083, [0,1,7,35], null];
  nodeArray[225]	= ["Tanum", 10010114035, [0,1,7,35], null];
  nodeArray[226]	= ["Tibro", 10010116062, [0,1,7,35], null];
  nodeArray[227]	= ["Tidaholm", 10010116085, [0,1,7,35], null];
  nodeArray[228]	= ["Tingsryd", 10010107063, [0,1,7,35], null];
  nodeArray[229]	= ["Tjrn", 10010114019, [0,1,7,35], null];
  nodeArray[230]	= ["Tomelilla", 10010111060, [0,1,7,35], null];
  nodeArray[231]	= ["Torss", 10010108034, [0,1,7,35], null];
  nodeArray[232]	= ["Tranemo", 10010115052, [0,1,7,35], null];
  nodeArray[233]	= ["Trans", 10010106087, [0,1,7,35], null];
  nodeArray[234]	= ["Trelleborg", 10010112087, [0,1,7,35], null];
  nodeArray[235]	= ["Trollhttan", 10010115081, [0,1,7,35], null];
  nodeArray[236]	= ["Treboda", 10010116063, [0,1,7,35], null];
  nodeArray[237]	= ["Uddevalla", 10010114085, [0,1,7,35], null];
  nodeArray[238]	= ["Ulricehamn", 10010115084, [0,1,7,35], null];
  nodeArray[239]	= ["Uppvidinge", 10010107060, [0,1,7,35], null];
  nodeArray[240]	= ["Vadstena", 10010105084, [0,1,7,35], null];
  nodeArray[241]	= ["Vaggeryd", 10010106065, [0,1,7,35], null];
  nodeArray[242]	= ["Valdemarsvik", 10010105063, [0,1,7,35], null];
  nodeArray[243]	= ["Vara", 10010116060, [0,1,7,35], null];
  nodeArray[244]	= ["Varberg", 10010113083, [0,1,7,35], null];
  nodeArray[245]	= ["Vellinge", 10010112033, [0,1,7,35], null];
  nodeArray[246]	= ["Vetlanda", 10010106085, [0,1,7,35], null];
  nodeArray[247]	= ["Vimmerby", 10010108084, [0,1,7,35], null];
  nodeArray[248]	= ["Vrgrda", 10010115027, [0,1,7,35], null];
  nodeArray[249]	= ["Vnersborg", 10010115080, [0,1,7,35], null];
  nodeArray[250]	= ["Vrnamo", 10010106083, [0,1,7,35], null];
  nodeArray[251]	= ["Vstervik", 10010108083, [0,1,7,35], null];
  nodeArray[252]	= ["Vxj", 10010107080, [0,1,7,35], null];
  nodeArray[253]	= ["Ydre", 10010105012, [0,1,7,35], null];
  nodeArray[254]	= ["Ystad", 10010112086, [0,1,7,35], null];
  nodeArray[255]	= ["storp", 10010111067, [0,1,7,35], null];
  nodeArray[256]	= ["tvidaberg", 10010105061, [0,1,7,35], null];
  nodeArray[257]	= ["lmhult", 10010107065, [0,1,7,35], null];
  nodeArray[258]	= ["ngelholm", 10010111082, [0,1,7,35], null];
  nodeArray[259]	= ["cker", 10010114007, [0,1,7,35], null];
  nodeArray[260]	= ["deshg", 10010105009, [0,1,7,35], null];
  nodeArray[261]	= ["rkelljunga", 10010111037, [0,1,7,35], null];
  nodeArray[262]	= ["stra Ginge", 10010111021, [0,1,7,35], null];
  nodeArray[263]	= ["Boxholm", 10010105060, [0,1,7,35], null];
  nodeArray[264]	= ["Arjeplog", 10010625006, [0,1,7,40], null];
  nodeArray[265]	= ["Arvidsjaur", 10010625005, [0,1,7,40], null];
  nodeArray[266]	= ["Boden", 10010625082, [0,1,7,40], null];
  nodeArray[267]	= ["Gllivare", 10010625023, [0,1,7,40], null];
  nodeArray[268]	= ["Haparanda", 10010625083, [0,1,7,40], null];
  nodeArray[269]	= ["Jokkmokk", 10010625010, [0,1,7,40], null];
  nodeArray[270]	= ["Kalix", 10010625014, [0,1,7,40], null];
  nodeArray[271]	= ["Kiruna", 10010625084, [0,1,7,40], null];
  nodeArray[272]	= ["Lule", 10010625080, [0,1,7,40], null];
  nodeArray[273]	= ["Pajala", 10010625021, [0,1,7,40], null];
  nodeArray[274]	= ["Pite", 10010625081, [0,1,7,40], null];
  nodeArray[275]	= ["lvsbyn", 10010625060, [0,1,7,40], null];
  nodeArray[276]	= ["verkalix", 10010625013, [0,1,7,40], null];
  nodeArray[277]	= ["vertorne", 10010625018, [0,1,7,40], null];
  nodeArray[278]	= ["Fagersta", 10010219082, [0,1,7,36], null];
  nodeArray[279]	= ["Hallstahammar", 10010219061, [0,1,7,36], null];
  nodeArray[280]	= ["Heby", 10010219017, [0,1,7,36], null];
  nodeArray[281]	= ["Kungsr", 10010219060, [0,1,7,36], null];
  nodeArray[282]	= ["Kping", 10010219083, [0,1,7,36], null];
  nodeArray[283]	= ["Norberg", 10010219062, [0,1,7,36], null];
  nodeArray[284]	= ["Sala", 10010219081, [0,1,7,36], null];
  nodeArray[285]	= ["Skinnskatteberg", 10010219004, [0,1,7,36], null];
  nodeArray[286]	= ["Surahammar", 10010219007, [0,1,7,36], null];
  nodeArray[287]	= ["Arboga", 10010219084, [0,1,7,36], null];
  nodeArray[288]	= ["Knivsta", 10010203083, [0,1,7,36], null];
  nodeArray[289]	= ["Vsters", 10010219080, [0,1,7,36], null];
  nodeArray[290]	= ["Nykping", 10010204080, [0,1,7,36], null];
  nodeArray[291]	= ["Oxelsund", 10010204081, [0,1,7,36], null];
  nodeArray[292]	= ["Botkyrka", 10010201027, [0,1,7,36], null];
  nodeArray[293]	= ["Danderyd", 10010201062, [0,1,7,36], null];
  nodeArray[294]	= ["Eker", 10010201025, [0,1,7,36], null];
  nodeArray[295]	= ["Enkping", 10010203081, [0,1,7,36], null];
  nodeArray[296]	= ["Eskilstuna", 10010204084, [0,1,7,36], null];
  nodeArray[297]	= ["Flen", 10010204082, [0,1,7,36], null];
  nodeArray[298]	= ["Gnesta", 10010204061, [0,1,7,36], null];
  nodeArray[299]	= ["Haninge", 10010201036, [0,1,7,36], null];
  nodeArray[300]	= ["Huddinge", 10010201026, [0,1,7,36], null];
  nodeArray[301]	= ["Hbo", 10010203005, [0,1,7,36], null];
  nodeArray[302]	= ["Jrflla", 10010201023, [0,1,7,36], null];
  nodeArray[303]	= ["Katrineholm", 10010204083, [0,1,7,36], null];
  nodeArray[304]	= ["Liding", 10010201086, [0,1,7,36], null];
  nodeArray[305]	= ["Nacka", 10010201082, [0,1,7,36], null];
  nodeArray[306]	= ["Norrtlje", 10010201088, [0,1,7,36], null];
  nodeArray[307]	= ["Nykvarn", 10010201040, [0,1,7,36], null];
  nodeArray[308]	= ["Nynshamn", 10010201092, [0,1,7,36], null];
  nodeArray[309]	= ["Salem", 10010201028, [0,1,7,36], null];
  nodeArray[310]	= ["Sigtuna", 10010201091, [0,1,7,36], null];
  nodeArray[311]	= ["Sollentuna", 10010201063, [0,1,7,36], null];
  nodeArray[312]	= ["Solna", 10010201084, [0,1,7,36], null];
  nodeArray[313]	= ["Stockholm", 10010201080, [0,1,7,36], null];
  nodeArray[314]	= ["Strngns", 10010204086, [0,1,7,36], null];
  nodeArray[315]	= ["Sundbyberg", 10010201083, [0,1,7,36], null];
  nodeArray[316]	= ["Sdertlje", 10010201081, [0,1,7,36], null];
  nodeArray[317]	= ["Tierp", 10010203060, [0,1,7,36], null];
  nodeArray[318]	= ["Trosa", 10010204088, [0,1,7,36], null];
  nodeArray[319]	= ["Tyres", 10010201038, [0,1,7,36], null];
  nodeArray[320]	= ["Tby", 10010201060, [0,1,7,36], null];
  nodeArray[321]	= ["Upplands-Bro", 10010201039, [0,1,7,36], null];
  nodeArray[322]	= ["Upplands-Vsby", 10010201014, [0,1,7,36], null];
  nodeArray[323]	= ["Uppsala", 10010203080, [0,1,7,36], null];
  nodeArray[324]	= ["Vallentuna", 10010201015, [0,1,7,36], null];
  nodeArray[325]	= ["Vaxholm", 10010201087, [0,1,7,36], null];
  nodeArray[326]	= ["Vingker", 10010204028, [0,1,7,36], null];
  nodeArray[327]	= ["Vrmd", 10010201020, [0,1,7,36], null];
  nodeArray[328]	= ["lvkarleby", 10010203019, [0,1,7,36], null];
  nodeArray[329]	= ["sterker", 10010201017, [0,1,7,36], null];
  nodeArray[330]	= ["sthammar", 10010203082, [0,1,7,36], null];
  nodeArray[331]	= ["Bergen", 10020212004, [0,1,8], null];
  nodeArray[332]	= ["Bod", 10020218006, [0,1,8], null];
  nodeArray[333]	= ["Geilo", 10020206007, [0,1,8], null];
  nodeArray[334]	= ["Kirkenes", 10020220016, [0,1,8], null];
  nodeArray[335]	= ["Lillehammer", 10020205008, [0,1,8], null];
  nodeArray[336]	= ["Oslo", 10020203001, [0,1,8], null];
  nodeArray[337]	= ["Stavanger", 10020211020, [0,1,8], null];
  nodeArray[338]	= ["Troms", 10020219025, [0,1,8], null];
  nodeArray[339]	= ["Trondheim", 10020216022, [0,1,8], null];
  nodeArray[340]	= ["Trysil", 10020204018, [0,1,8], null];
  nodeArray[341]	= ["lesund", 10020215036, [0,1,8], null];
  nodeArray[342]	= ["Nordkap", 10020220014, null, null];
  nodeArray[343]	= ["Bjrneborg", 10030403031, [0,1,9], null];
  nodeArray[344]	= ["Helsingfors", 10030404018, [0,1,9], null];
  nodeArray[345]	= ["Tavastehus", 10030404004, [0,1,9], null];
  nodeArray[346]	= ["Ilomantsi", 10030405023, [0,1,9], null];
  nodeArray[347]	= ["Jakobstad", 10030403003, [0,1,9], null];
  nodeArray[348]	= ["Joensuu", 10030405013, [0,1,9], null];
  nodeArray[349]	= ["Jokioinen", 10030404051, [0,1,9], null];
  nodeArray[350]	= ["Jyvskyl", 10030403022, [0,1,9], null];
  nodeArray[351]	= ["Kajana", 10030402008, [0,1,9], null];
  nodeArray[352]	= ["Kauhava", 10030403006, [0,1,9], null];
  nodeArray[353]	= ["Kemi", 10030401008, [0,1,9], null];
  nodeArray[354]	= ["Kilpisjrvi", 10030401002, [0,1,9], null];
  nodeArray[355]	= ["Kittil", 10030401003, [0,1,9], null];
  nodeArray[356]	= ["Kotka", 10030404022, [0,1,9], null];
  nodeArray[357]	= ["Kuopio", 10030405007, [0,1,9], null];
  nodeArray[358]	= ["Kuusamo", 10030402021, [0,1,9], null];
  nodeArray[359]	= ["Lahtis", 10030404005, [0,1,9], null];
  nodeArray[360]	= ["St Michel", 10030405002, [0,1,9], null];
  nodeArray[361]	= ["Muonio", 10030401011, [0,1,9], null];
  nodeArray[362]	= ["Nivala", 10030402005, [0,1,9], null];
  nodeArray[363]	= ["Pello", 10030401013, [0,1,9], null];
  nodeArray[364]	= ["Pudasjrvi", 10030402031, [0,1,9], null];
  nodeArray[365]	= ["Rovaniemi", 10030401006, [0,1,9], null];
  nodeArray[366]	= ["Salla", 10030401017, [0,1,9], null];
  nodeArray[367]	= ["Nyslott", 10030405003, [0,1,9], null];
  nodeArray[368]	= ["Sodankyl", 10030401004, [0,1,9], null];
  nodeArray[369]	= ["Suomussalmi", 10030402044, [0,1,9], null];
  nodeArray[370]	= ["Tammerfors", 10030403025, [0,1,9], null];
  nodeArray[371]	= ["Uleborg", 10030402001, [0,1,9], null];
  nodeArray[372]	= ["Vasa", 10030403005, [0,1,9], null];
  nodeArray[373]	= ["bo", 10030403043, [0,1,9], null];
  nodeArray[374]	= ["Mariehamn", 10030404001, [0,1,9], null];
  nodeArray[375]	= ["Bryssel", 10040620001, [0,1,15], null];
  nodeArray[376]	= ["Brugge", 10120621001, [0,1,15], null];
  nodeArray[377]	= ["Liege", 10120626001, [0,1,15], null];
  nodeArray[378]	= ["Charleroi", 10120623001, [0,1,15], null];
  nodeArray[379]	= ["Antwerpen", 10120628001, [0,1,15], null];
  nodeArray[380]	= ["Gent", 10120622001, [0,1,15], null];
  nodeArray[381]	= ["Sofia", 10054401001, [0,1,10], null];
  nodeArray[382]	= ["Varna", 10054401009, [0,1,10], null];
  nodeArray[383]	= ["Burgas", 10054401003, [0,1,10], null];
  nodeArray[384]	= ["Plovdiv", 10054401007, [0,1,10], null];
  nodeArray[385]	= ["Ruse", 10054401015, [0,1,10], null];
  nodeArray[386]	= ["Stara Zagora", 10054401017, [0,1,10], null];
  nodeArray[387]	= ["Larnaca", 10062001208, [0,1,29], null];
  nodeArray[388]	= ["Paphos", 10062001770, [0,1,29], null];
  nodeArray[389]	= ["Nicosia", 10062001286, [0,1,29], null];
  nodeArray[390]	= ["Limassol", 10062001771, [0,1,29], null];
  nodeArray[391]	= ["Kpenhamn", 10072001204, [0,1,11], null];
  nodeArray[392]	= ["Aalborg", 10070301002, [0,1,11], null];
  nodeArray[393]	= ["Esbjerg", 10070304006, [0,1,11], null];
  nodeArray[394]	= ["Odense", 10070308019, [0,1,11], null];
  nodeArray[395]	= ["Nykbing", 10070310011, [0,1,11], null];
  nodeArray[396]	= ["Skagen", 10070301025, [0,1,11], null];
  nodeArray[397]	= ["rhus", 10070307026, [0,1,11], null];
  nodeArray[398]	= ["Thisted", 10070302015, [0,1,11], null];
  nodeArray[399]	= ["Kolding", 10070306011, [0,1,11], null];
  nodeArray[400]	= ["Kalundborg", 10070309012, [0,1,11], null];
  nodeArray[401]	= ["Nakskov", 10070310010, [0,1,11], null];
  nodeArray[402]	= ["Holbk", 10070309008, [0,1,11], null];
  nodeArray[403]	= ["Viborg", 10070302017, [0,1,11], null];
  nodeArray[404]	= ["Holstebro", 10070303007, [0,1,11], null];
  nodeArray[405]	= ["Herning", 10070303005, [0,1,11], null];
  nodeArray[406]	= ["Silkeborg", 10070307022, [0,1,11], null];
  nodeArray[407]	= ["Snderborg", 10070305020, [0,1,11], null];
  nodeArray[408]	= ["Svendborg", 10070308024, [0,1,11], null];
  nodeArray[409]	= ["Nstved", 10070310009, [0,1,11], null];
  nodeArray[410]	= ["Rnne", 10070314005, [0,1,11], null];
  nodeArray[411]	= ["Tallinn", 10081101013, [0,1,12], null];
  nodeArray[412]	= ["Narva", 10081101005, [0,1,12], null];
  nodeArray[413]	= ["Tartu", 10081101014, [0,1,12], null];
  nodeArray[414]	= ["Prnu", 10081101009, [0,1,12], null];
  nodeArray[415]	= ["Biarritz", 10102001481, [0,1,13], null];
  nodeArray[416]	= ["Bordeaux", 10102001054, [0,1,13], null];
  nodeArray[417]	= ["Chamonix", 10100801111, [0,1,13], null];
  nodeArray[418]	= ["Korsika", 10102001009, [0,1,13], null];
  nodeArray[419]	= ["Nice", 10100801040, [0,1,13], null];
  nodeArray[420]	= ["Paris", 10100801049, [0,1,13], null];
  nodeArray[421]	= ["Val d'Isere", 10100801130, [0,1,13], null];
  nodeArray[422]	= ["Brest", 10100801013, [0,1,13], null];
  nodeArray[423]	= ["Lyon", 10100801106, [0,1,13], null];
  nodeArray[424]	= ["Dijon", 10100801034, [0,1,13], null];
  nodeArray[425]	= ["Le Havre", 10100801141, [0,1,13], null];
  nodeArray[426]	= ["Nantes", 10100801015, [0,1,13], null];
  nodeArray[427]	= ["Toulouse", 10100801142, [0,1,13], null];
  nodeArray[428]	= ["Limoges", 10100801143, [0,1,13], null];
  nodeArray[429]	= ["Le Mans", 10100801144, [0,1,13], null];
  nodeArray[430]	= ["Strasbourg", 10100801145, [0,1,13], null];
  nodeArray[431]	= ["Marseille", 10100801140, [0,1,13], null];
  nodeArray[432]	= ["Montpellier", 10100801147, [0,1,13], null];
  nodeArray[433]	= ["Perpignan", 10102001310, [0,1,13], null];
  nodeArray[434]	= ["Aten", 10114501001, [0,1,14], null];
  nodeArray[435]	= ["Kreta", 10114501014, [0,1,14], null];
  nodeArray[436]	= ["Rhodos", 10114501013, [0,1,14], null];
  nodeArray[437]	= ["Thessaloniki", 10114501003, [0,1,14], null];
  nodeArray[438]	= ["Naxos", 10114501011, [0,1,14], null];
  nodeArray[439]	= ["Limnos", 10114501007, [0,1,14], null];
  nodeArray[440]	= ["Lesvos", 10114501026, [0,1,14], null];
  nodeArray[441]	= ["Skyros", 10114501025, [0,1,14], null];
  nodeArray[442]	= ["Samos", 10114501027, [0,1,14], null];
  nodeArray[443]	= ["Milos", 10114501028, [0,1,14], null];
  nodeArray[444]	= ["Korfu", 10114501005, [0,1,14], null];
  nodeArray[445]	= ["Souda(Kreta)", 10114501022, [0,1,14], null];
  nodeArray[446]	= ["Kythira", 10114501023, [0,1,14], null];
  nodeArray[447]	= ["Amsterdam", 10120601039, [0,1,15], null];
  nodeArray[448]	= ["Gronningen", 10120601021, [0,1,15], null];
  nodeArray[449]	= ["Maastricht", 10120601025, [0,1,15], null];
  nodeArray[450]	= ["Arnhem", 10120601014, [0,1,15], null];
  nodeArray[451]	= ["Haag", 10120601083, [0,1,15], null];
  nodeArray[452]	= ["Dublin", 10132516001, [0,1,16], null];
  nodeArray[453]	= ["Cork", 10132526001, [0,1,16], null];
  nodeArray[454]	= ["Limerick", 10132522001, [0,1,16], null];
  nodeArray[455]	= ["Longford", 10132510001, [0,1,16], null];
  nodeArray[456]	= ["Reykjavik", 10144701001, [0,1,17], null];
  nodeArray[457]	= ["Isafjrdhur", 10144701005, [0,1,17], null];
  nodeArray[458]	= ["Akureyri", 10144701002, [0,1,17], null];
  nodeArray[459]	= ["Husavik", 10144701003, [0,1,17], null];
  nodeArray[460]	= ["Vestmannaeyjar", 10144701006, [0,1,17], null];
  nodeArray[461]	= ["Bolzano", 10151001035, [0,1,18], null];
  nodeArray[462]	= ["Catania", 10151001042, [0,1,18], null];
  nodeArray[463]	= ["Cortina", 10151001006, [0,1,18], null];
  nodeArray[464]	= ["Locarno", 10150701019, [0,1,18], null];
  nodeArray[465]	= ["Milano", 10151001074, [0,1,18], null];
  nodeArray[466]	= ["Neapel", 10151001073, [0,1,18], null];
  nodeArray[467]	= ["Palermo", 10151001082, [0,1,18], null];
  nodeArray[468]	= ["Rimini", 10151001095, [0,1,18], null];
  nodeArray[469]	= ["Rom", 10151001096, [0,1,18], null];
  nodeArray[470]	= ["Venedig", 10151001118, [0,1,18], null];
  nodeArray[471]	= ["Bari", 10151001029, [0,1,18], null];
  nodeArray[472]	= ["Brindisi", 10151001037, [0,1,18], null];
  nodeArray[473]	= ["Cagliari", 10151001038, [0,1,18], null];
  nodeArray[474]	= ["Florens", 10151001053, [0,1,18], null];
  nodeArray[475]	= ["Genua", 10151001057, [0,1,18], null];
  nodeArray[476]	= ["Perugia", 10151001083, [0,1,18], null];
  nodeArray[477]	= ["Pescara", 10151001085, [0,1,18], null];
  nodeArray[478]	= ["Pisa", 10151001087, [0,1,18], null];
  nodeArray[479]	= ["Taranto", 10151001106, [0,1,18], null];
  nodeArray[480]	= ["Trieste", 10151001112, [0,1,18], null];
  nodeArray[481]	= ["Bologna", 10151001034, [0,1,18], null];
  nodeArray[482]	= ["Zagreb", 10164803003, [0,1,19], null];
  nodeArray[483]	= ["Split", 10164803001, [0,1,19], null];
  nodeArray[484]	= ["Pula", 10164803002, [0,1,19], null];
  nodeArray[485]	= ["Dubrovnik", 10164803004, [0,1,19], null];
  nodeArray[486]	= ["Luxemburg", 10120650001, [0,1,15], null];
  nodeArray[487]	= ["Ljubljana", 10163401001, [0,1,19], null];
  nodeArray[488]	= ["Izola", 10163401002, [0,1,19], null];
  nodeArray[489]	= ["Celje", 10163401003, [0,1,19], null];
  nodeArray[490]	= ["Bihac", 10164301002, [0,1,19], null];
  nodeArray[491]	= ["Mostar", 10164301005, [0,1,19], null];
  nodeArray[492]	= ["Sarajevo", 10164301001, [0,1,19], null];
  nodeArray[493]	= ["Tuzla", 10164301007, [0,1,19], null];
  nodeArray[494]	= ["Zenica", 10164301008, [0,1,19], null];
  nodeArray[495]	= ["Belgrad", 10164601001, [0,1,19], null];
  nodeArray[496]	= ["Bar", 10164601003, [0,1,19], null];
  nodeArray[497]	= ["Skopje", 10162601001, [0,1,19], null];
  nodeArray[498]	= ["Strumica", 10162601007, [0,1,19], null];
  nodeArray[499]	= ["Prilep", 10162601006, [0,1,19], null];
  nodeArray[500]	= ["Bitola", 10162601002, [0,1,19], null];
  nodeArray[501]	= ["Stip", 10162601008, [0,1,19], null];
  nodeArray[502]	= ["Bratislava", 10183702001, [0,1,20], null];
  nodeArray[503]	= ["Bystrica", 10183702003, [0,1,20], null];
  nodeArray[504]	= ["Kosice", 10183702002, [0,1,20], null];
  nodeArray[505]	= ["Riga", 10182201001, [0,1,12], null];
  nodeArray[506]	= ["Liepaja", 10082201023, [0,1,12], null];
  nodeArray[507]	= ["Daugavpils", 10082201038, [0,1,12], null];
  nodeArray[508]	= ["Aluksne", 10082201004, [0,1,12], null];
  nodeArray[509]	= ["Vilnius", 10082401001, [0,1,12], null];
  nodeArray[510]	= ["Klaipeda", 10082401016, [0,1,12], null];
  nodeArray[511]	= ["Kaunas", 10082401003, [0,1,12], null];
  nodeArray[512]	= ["Panevezys", 10082401025, [0,1,12], null];
  nodeArray[513]	= ["Warszawa", 10201201290, [0,1,21], null];
  nodeArray[514]	= ["Gdansk", 10201201047, [0,1,21], null];
  nodeArray[515]	= ["Szczecin", 10201201255, [0,1,21], null];
  nodeArray[516]	= ["Poznan", 10201201201, [0,1,21], null];
  nodeArray[517]	= ["Wroclaw", 10201201305, [0,1,21], null];
  nodeArray[518]	= ["Lublin", 10201201135, [0,1,21], null];
  nodeArray[519]	= ["Krakow", 10201201105, [0,1,21], null];
  nodeArray[520]	= ["Bialystok", 10201201009, [0,1,21], null];
  nodeArray[521]	= ["Elblag", 10201201044, [0,1,21], null];
  nodeArray[522]	= ["Koszalin", 10201201103, [0,1,21], null];
  nodeArray[523]	= ["Czestochowa", 10201201036, [0,1,21], null];
  nodeArray[524]	= ["Lodz", 10201201127, [0,1,21], null];
  nodeArray[525]	= ["Torun", 10201201279, [0,1,21], null];
  nodeArray[526]	= ["Rzeszow", 10201201227, [0,1,21], null];
  nodeArray[527]	= ["Radom", 10201201216, [0,1,21], null];
  nodeArray[528]	= ["Katowice", 10201201086, [0,1,21], null];
  nodeArray[529]	= ["Olsztyn", 10201201173, [0,1,21], null];
  nodeArray[530]	= ["Lagos", 10213011002, [0,1,22], null];
  nodeArray[531]	= ["Lissabon", 10213007002, [0,1,22], null];
  nodeArray[532]	= ["Porto", 10213003001, [0,1,22], null];
  nodeArray[533]	= ["Viana do Castelo", 10213001002, [0,1,22], null];
  nodeArray[534]	= ["Portalegre", 10213009001, [0,1,22], null];
  nodeArray[535]	= ["Braga", 10213001001, [0,1,22], null];
  nodeArray[536]	= ["Evora", 10213009002, [0,1,22], null];
  nodeArray[537]	= ["Funchal", 10213012001, [0,1,22], null];
  nodeArray[538]	= ["Horta", 10213013004, [0,1,22], null];
  nodeArray[539]	= ["Bukarest", 10223101001, [0,1,23], null];
  nodeArray[540]	= ["Arad", 10223101002, [0,1,23], null];
  nodeArray[541]	= ["Constanta", 10223101014, [0,1,23], null];
  nodeArray[542]	= ["Cluj Napoca", 10223101004, [0,1,23], null];
  nodeArray[543]	= ["Iasi", 10223101003, [0,1,23], null];
  nodeArray[544]	= ["Sibiu", 10223101007, [0,1,23], null];
  nodeArray[545]	= ["Arkhangelsk", 10233201003, [0,1,24], null];
  nodeArray[546]	= ["Moskva", 10233201001, [0,1,24], null];
  nodeArray[547]	= ["Perm", 10233201006, [0,1,24], null];
  nodeArray[548]	= ["Murmansk", 10233201009, [0,1,24], null];
  nodeArray[549]	= ["S:t Petersburg", 10233201002, [0,1,24], null];
  nodeArray[550]	= ["Volgograd", 10233201008, [0,1,24], null];
  nodeArray[551]	= ["Nizjnij Novgorod", 10233201005, [0,1,24], null];
  nodeArray[552]	= ["Smolensk", 10233201007, [0,1,24], null];
  nodeArray[553]	= ["Astrachan", 10233201004, [0,1,24], null];
  nodeArray[554]	= ["Geneve", 10240701007, [0,1,25], null];
  nodeArray[555]	= ["Verbier", 10240701030, [0,1,25], null];
  nodeArray[556]	= ["Zermatt", 10240701032, [0,1,25], null];
  nodeArray[557]	= ["Zurich", 10240701024, [0,1,25], null];
  nodeArray[558]	= ["Basel", 10240701004, [0,1,25], null];
  nodeArray[559]	= ["S.t moritz", 10240701029, [0,1,25], null];
  nodeArray[560]	= ["Alicante", 10253515001, [0,1,26], null];
  nodeArray[561]	= ["Barcelona", 10253510001, [0,1,26], null];
  nodeArray[562]	= ["Las Palmas", 10253506007, [0,1,26], null];
  nodeArray[563]	= ["Madrid", 10253501001, [0,1,26], null];
  nodeArray[564]	= ["Malaga", 10253502007, [0,1,26], null];
  nodeArray[565]	= ["Mallorca (Palma)", 10253505002, [0,1,26], null];
  nodeArray[566]	= ["Sevilla", 10253502008, [0,1,26], null];
  nodeArray[567]	= ["Teneriffa", 10253506006, [0,1,26], null];
  nodeArray[568]	= ["Lanzarote", 10253506005, [0,1,26], null];
  nodeArray[569]	= ["Fuerteventura", 10253506008, [0,1,26], null];
  nodeArray[570]	= ["La Coruna", 10253511001, [0,1,26], null];
  nodeArray[571]	= ["Gijn", 10253504001, [0,1,26], null];
  nodeArray[572]	= ["Bilbao", 10253514001, [0,1,26], null];
  nodeArray[573]	= ["Pamplona", 10253513001, [0,1,26], null];
  nodeArray[574]	= ["Valladolid", 10253508007, [0,1,26], null];
  nodeArray[575]	= ["Zaragoza", 10253503003, [0,1,26], null];
  nodeArray[576]	= ["Valencia", 10253515003, [0,1,26], null];
  nodeArray[577]	= ["Cordoba", 10253502003, [0,1,26], null];
  nodeArray[578]	= ["Albacete", 10253507001, [0,1,26], null];
  nodeArray[579]	= ["Cartagena", 10253518001, [0,1,26], null];
  nodeArray[580]	= ["Badajoz", 10253517006, [0,1,26], null];
  nodeArray[581]	= ["Salamanca", 10253508006, [0,1,26], null];
  nodeArray[582]	= ["Edinburgh", 10263662001, [0,1,27], null];
  nodeArray[583]	= ["London", 10263601001, [0,1,27], null];
  nodeArray[584]	= ["Glasgow", 10263657001, [0,1,27], null];
  nodeArray[585]	= ["Newcastle", 10263603001, [0,1,27], null];
  nodeArray[586]	= ["Liverpool", 10263612001, [0,1,27], null];
  nodeArray[587]	= ["Nottingham", 10263626001, [0,1,27], null];
  nodeArray[588]	= ["Bristol", 10263635001, [0,1,27], null];
  nodeArray[589]	= ["Plymoth", 10263644001, [0,1,27], null];
  nodeArray[590]	= ["Belfast", 10263655004, [0,1,27], null];
  nodeArray[591]	= ["Portsmouth", 10263641001, [0,1,27], null];
  nodeArray[592]	= ["Orkney arna", 10263660002, [0,1,27], null];
  nodeArray[593]	= ["Aberdeen", 10263658001, [0,1,27], null];
  nodeArray[594]	= ["Birmingham", 10263629002, [0,1,27], null];
  nodeArray[595]	= ["Jersey", 10263665001, [0,1,27], null];
  nodeArray[596]	= ["Prag", 10272001323, [0,1,28], null];
  nodeArray[597]	= ["Plzen", 10273701002, [0,1,28], null];
  nodeArray[598]	= ["Brno", 10273701003, [0,1,28], null];
  nodeArray[599]	= ["Ostrava", 10273701004, [0,1,28], null];
  nodeArray[600]	= ["Ankara", 10294101001, [0,1,29], null];
  nodeArray[601]	= ["Antalya", 10294101008, [0,1,29], null];
  nodeArray[602]	= ["Izmir", 10294101010, [0,1,29], null];
  nodeArray[603]	= ["Balikesir", 10294101005, [0,1,29], null];
  nodeArray[604]	= ["Istanbul", 10294101009, [0,1,29], null];
  nodeArray[605]	= ["Adana", 10294101019, [0,1,29], null];
  nodeArray[606]	= ["Kayseri", 10294101020, [0,1,29], null];
  nodeArray[607]	= ["Samsun", 10294101018, [0,1,29], null];
  nodeArray[608]	= ["Berlin", 10300508001, [0,1,30], null];
  nodeArray[609]	= ["Frankfurt", 10300510018, [0,1,30], null];
  nodeArray[610]	= ["Kiel", 10300501005, [0,1,30], null];
  nodeArray[611]	= ["Hamburg", 10300503001, [0,1,30], null];
  nodeArray[612]	= ["Bremen", 10300505001, [0,1,30], null];
  nodeArray[613]	= ["Dortmund", 10300509019, [0,1,30], null];
  nodeArray[614]	= ["Hannover", 10300504030, [0,1,30], null];
  nodeArray[615]	= ["Leipzig", 10300512003, [0,1,30], null];
  nodeArray[616]	= ["Dresden", 10300512012, [0,1,30], null];
  nodeArray[617]	= ["Bonn", 10300509058, [0,1,30], null];
  nodeArray[618]	= ["Kassel", 10300510001, [0,1,30], null];
  nodeArray[619]	= ["Zwickau", 10300512022, [0,1,30], null];
  nodeArray[620]	= ["Saarbrcken", 10300514005, [0,1,30], null];
  nodeArray[621]	= ["Mannheim", 10300515001, [0,1,30], null];
  nodeArray[622]	= ["Wrzburg", 10300516018, [0,1,30], null];
  nodeArray[623]	= ["Nrnberg", 10300516037, [0,1,30], null];
  nodeArray[624]	= ["Stuttgart", 10300515021, [0,1,30], null];
  nodeArray[625]	= ["Mnchen", 10300516081, [0,1,30], null];
  nodeArray[626]	= ["Regensburg", 10300516045, [0,1,30], null];
  nodeArray[627]	= ["Freiburg", 10300515034, [0,1,30], null];
  nodeArray[628]	= ["Odessa", 10313801008, [0,1,31], null];
  nodeArray[629]	= ["Kiev", 10313801001, [0,1,31], null];
  nodeArray[630]	= ["Dnipropetrovsk", 10313801006, [0,1,31], null];
  nodeArray[631]	= ["Kharkiv", 10313801004, [0,1,31], null];
  nodeArray[632]	= ["Lviv", 10313801011, [0,1,31], null];
  nodeArray[633]	= ["Budapest", 10323901001, [0,1,32], null];
  nodeArray[634]	= ["Pcs", 10323901008, [0,1,32], null];
  nodeArray[635]	= ["Szeged", 10323901012, [0,1,32], null];
  nodeArray[636]	= ["Gyr", 10323901004, [0,1,32], null];
  nodeArray[637]	= ["Miskolc", 10323901002, [0,1,32], null];
  nodeArray[638]	= ["Debrecen", 10323901006, [0,1,32], null];
  nodeArray[639]	= ["Szombathely", 10323901003, [0,1,32], null];
  nodeArray[640]	= ["Minsk", 10334001001, [0,1,33], null];
  nodeArray[641]	= ["Brest", 10334001004, [0,1,33], null];
  nodeArray[642]	= ["Babruysk", 10334001007, [0,1,33], null];
  nodeArray[643]	= ["Orsha", 10334001005, [0,1,33], null];
  nodeArray[644]	= ["Pinsk", 10334001002, [0,1,33], null];
  nodeArray[645]	= ["Mazyr", 10334001003, [0,1,33], null];
  nodeArray[646]	= ["Polatsk", 10334001006, [0,1,33], null];
  nodeArray[647]	= ["Badgastein", 10340901029, [0,1,34], null];
  nodeArray[648]	= ["Innsbruck", 10340901010, [0,1,34], null];
  nodeArray[649]	= ["Kitzbhel", 10340901036, [0,1,34], null];
  nodeArray[650]	= ["Saalbach", 10340901041, [0,1,34], null];
  nodeArray[651]	= ["Salzburg", 10340901019, [0,1,34], null];
  nodeArray[652]	= ["Wien", 10340901024, [0,1,34], null];
  nodeArray[653]	= ["Linz", 10340901017, [0,1,34], null];
  nodeArray[654]	= ["Graz", 10340901008, [0,1,34], null];
  nodeArray[655]	= ["Klagenfurt", 10340901012, [0,1,34], null];
  nodeArray[656]	= ["Bregenz", 10340901046, [0,1,34], null];
  nodeArray[657]	= ["Acapulco", 142001005, [0,4], null];
  nodeArray[658]	= ["Asuncion", 141603001, [0,5], null];
  nodeArray[659]	= ["Barbados", 142001035, [0,5], null];
  nodeArray[660]	= ["Bogota", 141501003, [0,5], null];
  nodeArray[661]	= ["Buenos Aires", 141901002, [0,5], null];
  nodeArray[662]	= ["Caracas", 141403001, [0,5], null];
  nodeArray[663]	= ["Havanna", 142001157, [0,5], null];
  nodeArray[664]	= ["Kingston", 142001193, [0,5], null];
  nodeArray[665]	= ["La Paz", 141601003, [0,5], null];
  nodeArray[666]	= ["Lima", 141405001, [0,5], null];
  nodeArray[667]	= ["Montevideo", 142001265, [0,5], null];
  nodeArray[668]	= ["Port au Prince", 142001319, [0,5], null];
  nodeArray[669]	= ["Quito", 141404001, [0,5], null];
  nodeArray[670]	= ["Rio de Janeiro", 142101008, [0,5], null];
  nodeArray[671]	= ["Santiago", 141701001, [0,5], null];
  nodeArray[672]	= ["Adelaide", 152001008, [0,6], null];
  nodeArray[673]	= ["Auckland", 158201002, [0,6], null];
  nodeArray[674]	= ["Cairns", 152001074, [0,6], null];
  nodeArray[675]	= ["Christchurch", 158202005, [0,6], null];
  nodeArray[676]	= ["Darwin", 152001102, [0,6], null];
  nodeArray[677]	= ["Melbourne", 152001252, [0,6], null];
  nodeArray[678]	= ["Perth", 152001311, [0,6], null];
  nodeArray[679]	= ["Sydney", 152001386, [0,6], null];
  nodeArray[680]	= ["Wellington", 158201010, [0,6], null];
  nodeArray[681]	= ["Anchorage", 136102002, [0,4], null];
  nodeArray[682]	= ["Aspen", 132001863, [0,4], null];
  nodeArray[683]	= ["Atlanta", 136110001, [0,4], null];
  nodeArray[684]	= ["Calgary", 135001003, [0,4], null];
  nodeArray[685]	= ["Chicago", 136112002, [0,4], null];
  nodeArray[686]	= ["Dallas", 136142003, [0,4], null];
  nodeArray[687]	= ["Denver", 136106001, [0,4], null];
  nodeArray[688]	= ["Fairbanks", 136102003, [0,4], null];
  nodeArray[689]	= ["Guatemala", 132001148, [0,4], null];
  nodeArray[690]	= ["Honolulu", 136149001, [0,4], null];
  nodeArray[691]	= ["Houston", 136142004, [0,4], null];
  nodeArray[692]	= ["Los Angeles", 136105003, [0,4], null];
  nodeArray[693]	= ["Managua", 132001241, [0,4], null];
  nodeArray[694]	= ["Memphis", 136141002, [0,4], null];
  nodeArray[695]	= ["Mexico city", 132001255, [0,4], null];
  nodeArray[696]	= ["Miami", 136109004, [0,4], null];
  nodeArray[697]	= ["Minneapolis", 136122002, [0,4], null];
  nodeArray[698]	= ["Montreal", 135009001, [0,4], null];
  nodeArray[699]	= ["New Orleans", 136117002, [0,4], null];
  nodeArray[700]	= ["New York", 136131003, [0,4], null];
  nodeArray[701]	= ["Phoenix", 136103001, [0,4], null];
  nodeArray[702]	= ["Quebec", 135009002, [0,4], null];
  nodeArray[703]	= ["San Franscisco", 136105002, [0,4], null];
  nodeArray[704]	= ["Seattle", 136146002, [0,4], null];
  nodeArray[705]	= ["Toronto", 135007002, [0,4], null];
  nodeArray[706]	= ["Vancouver", 135003001, [0,4], null];
  nodeArray[707]	= ["Washington", 132001425, [0,4], null];
  nodeArray[708]	= ["Whistler", 135003002, [0,4], null];
  nodeArray[709]	= ["Winnipeg", 135004001, [0,4], null];
  nodeArray[710]	= ["San Jos", 131406001, [0,4], null];
  nodeArray[711]	= ["Abu Dhabi", 122001004, [0,3], null];
  nodeArray[712]	= ["Bagdad", 122001029, [0,3], null];
  nodeArray[713]	= ["Bali (Denpasar)", 122001103, [0,3], null];
  nodeArray[714]	= ["Bangkok", 122001034, [0,3], null];
  nodeArray[715]	= ["Beirut", 122001039, [0,3], null];
  nodeArray[716]	= ["Bombay", 122001052, [0,3], null];
  nodeArray[717]	= ["Calcutta", 122001076, [0,3], null];
  nodeArray[718]	= ["Eilat", 122001118, [0,3], null];
  nodeArray[719]	= ["Hongkong", 125101010, [0,3], null];
  nodeArray[720]	= ["Irkutsk", 122001170, [0,3], null];
  nodeArray[721]	= ["Jakarta (Djakarta)", 122001107, [0,3], null];
  nodeArray[722]	= ["Jakutsk", 122001172, [0,3], null];
  nodeArray[723]	= ["Jerusalem", 122001176, [0,3], null];
  nodeArray[724]	= ["Kabul", 122001179, [0,3], null];
  nodeArray[725]	= ["Karachi (Pakistan)", 122001185, [0,3], null];
  nodeArray[726]	= ["Manila", 122001245, [0,3], null];
  nodeArray[727]	= ["Mauritius", 122001457, [0,3], null];
  nodeArray[728]	= ["New Delhi", 122001281, [0,3], null];
  nodeArray[729]	= ["Novosibirsk", 122001290, [0,3], null];
  nodeArray[730]	= ["Peking", 122001309, [0,3], null];
  nodeArray[731]	= ["Phuket air", 122001464, [0,3], null];
  nodeArray[732]	= ["Riadh (Rijad)", 122001338, [0,3], null];
  nodeArray[733]	= ["Rostov", 122001487, [0,3], null];
  nodeArray[734]	= ["Ho Chi Minh City", 122001347, [0,3], null];
  nodeArray[735]	= ["Seuol", 122001366, [0,3], null];
  nodeArray[736]	= ["Shanghai", 125101008, [0,3], null];
  nodeArray[737]	= ["Singapore", 122001370, [0,3], null];
  nodeArray[738]	= ["Sri Lanka", 122001091, [0,3], null];
  nodeArray[739]	= ["Tasjkent", 122001393, [0,3], null];
  nodeArray[740]	= ["Tbilisi", 125601001, [0,3], null];
  nodeArray[741]	= ["Teheran", 122001396, [0,3], null];
  nodeArray[742]	= ["Tel Aviv", 122001395, [0,3], null];
  nodeArray[743]	= ["Tokyo", 122001400, [0,3], null];
  nodeArray[744]	= ["Ulan Bator", 122001411, [0,3], null];
  nodeArray[745]	= ["Vladivostok", 123229001, [0,3], null];
  nodeArray[746]	= ["Taipei", 125105001, [0,3], null];
  nodeArray[747]	= ["Abidjan", 112001003, [0,2], null];
  nodeArray[748]	= ["Accra", 112001006, [0,2], null];
  nodeArray[749]	= ["Addis Abeba", 112001007, [0,2], null];
  nodeArray[750]	= ["Alger", 112001011, [0,2], null];
  nodeArray[751]	= ["Antananarivo", 112001391, [0,2], null];
  nodeArray[752]	= ["Casablanca", 112001081, [0,2], null];
  nodeArray[753]	= ["Dakar", 112001098, [0,2], null];
  nodeArray[754]	= ["Dar-es-Salaam", 112001101, [0,2], null];
  nodeArray[755]	= ["Durban", 112001114, [0,2], null];
  nodeArray[756]	= ["Free Town", 112001129, [0,2], null];
  nodeArray[757]	= ["Gabarone", 117202001, [0,2], null];
  nodeArray[758]	= ["Gambia", 112001133, [0,2], null];
  nodeArray[759]	= ["Harare", 112001156, [0,2], null];
  nodeArray[760]	= ["Johannesburg", 112001177, [0,2], null];
  nodeArray[761]	= ["Kairo", 112001180, [0,2], null];
  nodeArray[762]	= ["Kapstaden", 112001184, [0,2], null];
  nodeArray[763]	= ["Kinshasa", 112001484, [0,2], null];
  nodeArray[764]	= ["Lagos", 112001206, [0,2], null];
  nodeArray[765]	= ["Libreville", 117105001, [0,2], null];
  nodeArray[766]	= ["Luanda", 112001232, [0,2], null];
  nodeArray[767]	= ["Maputo", 117204001, [0,2], null];
  nodeArray[768]	= ["Mombasa", 112001461, [0,2], null];
  nodeArray[769]	= ["Monrovia", 112001264, [0,2], null];
  nodeArray[770]	= ["Nairobi", 112001272, [0,2], null];
  nodeArray[771]	= ["Nampula", 117204004, [0,2], null];
  nodeArray[772]	= ["Port Elizabeth", 117901006, [0,2], null];
  nodeArray[773]	= ["Seychellerna", 112001367, [0,2], null];
  nodeArray[774]	= ["Tarapolis (Tripoli)", 112001405, [0,2], null];
  nodeArray[775]	= ["Tunis", 112001409, [0,2], null];